@@ -19,7 +19,8 @@ import records #record data
 
 #load language file
 import i18n
-_ = i18n.language.gettext
+#_ = i18n.language.gettext
+_ = i18n.language.ugettext
 
 ###########################################################################
 ## Load the configuration from the config file
